"""Default dummy values configuration for PII replacement."""

DEFAULT_DUMMY_VALUES = {
    "work": "[WORK REDACTED]",
    "booking number": "BOOK123456",
    "personally identifiable information": "[DATA REDACTED]",
    "driver licence": "DL-0000000000000",
    "person": ["[NAME REDACTED1]", "[NAME REDACTED2]", "[NAME REDACTED3]", "[NAME REDACTED4]", "[NAME REDACTED5]"],
    "book": "Sample Book Title",
    "full address": "[ADDRESS REDACTED]",
    "company": ["[COMPANY NAME REDACTED1]", "[COMPANY NAME REDACTED2]", "[COMPANY NAME REDACTED3]", "[COMPANY NAME REDACTED4]", "[COMPANY NAME REDACTED5]"],
    "email": "example@mail.com",
    "passport number": "A0000000",
    "Social Security Number": "000-00-0000",
    "phone number": "+91-9000000000",
  
    "Aadhaar number": ["0000 1111 2222", "0000 3333 4444", "0000 5555 6666", "0000 7777 8888", "0000 9999 0000"],
    "Aadhaar Enrolment ID": "0000/00000/00000",
    "Aadhaar Virtual ID": "0000000000000000",
    "PAN number": ["ABCDE1234F", "ABCDE1234G", "ABCDE1234H", "ABCDE1234I", "ABCDE1234J"],
    "Voter ID number": "ABC1234567",
    "EPIC number": "EPIC000000",
    "Bank account number": "000000000000",
    "IFSC code": "BANK0000000",
    "MICR code": "000000000",
    "SWIFT/BIC code": "BANKINBBXXX",
    "UPI ID": "user@bank",
    "Credit card number": "4111 1111 1111 1111",
    "Debit card number": "5000 0000 0000 0000",
    "Cheque number": "000000",
    "Demand draft number": ["DD0000000", "DD0000001", "DD0000002", "DD0000003", "DD0000004"],
  
    "CIN number": "U12345DL2000PLC000000",
    "LLPIN": "AAA-0000",
    "GSTIN": ["22AAAAA0000A1Z5", "22AAAAA0000A1Z6", "22AAAAA0000A1Z7", "22AAAAA0000A1Z8", "22AAAAA0000A1Z9"],
    "TAN number": "ABCD12345E",
    "TIN number": "00000000000",
    "IEC number": ["0512345678", "0512345679", "0512345680", "0512345681", "0512345682"],
    "Udyam registration number": "UDYAM-XX-00-0000000",
    "DIN": "00000000",
  
    "Case number": ["CS/000/2023", "CS/001/2023", "CS/002/2023", "CS/003/2023", "CS/004/2023"],
    "CNR number": "DLHC010000002023",
    "Diary number": "D-2023-00000",
    "Filing number": ["F-00000-2023", "F-00001-2023", "F-00002-2023", "F-00003-2023", "F-00004-2023"],
    "Court order number": "CO-2023-00000",
    "Writ petition number": "WP-0000-2023",
    "Criminal appeal number": ["CRA-2023-0000", "CRA-2023-0001", "CRA-2023-0002", "CRA-2023-0003", "CRA-2023-0004"],
    "FIR number": "FIR-000/2023",
    "Crime number": "CR-00000-2023",
    "GD/DD entry number": ["DD-0000-2023", "DD-0001-2023", "DD-0002-2023", "DD-0003-2023", "DD-0004-2023"],
    "Charge sheet number": "CSN-00000",
    "Arrest memo number": "AM-0000-2023",
    "Seizure memo number": ["SM-0000-2023", "SM-0001-2023", "SM-0002-2023", "SM-0003-2023", "SM-0004-2023"],
    "MLC number": "MLC-00000",
  
    "Vehicle registration number": ["DL1C0000", "DL1C0001", "DL1C0002", "DL1C0003", "DL1C0004"],
    "RC number": "RC000000",
    "Chassis number": "CH00000ABC0000",
    "Engine number": ["EN00000000", "EN00000001", "EN00000002", "EN00000003", "EN00000004"],
    "e-challan number": "CHLN00000",
    "PUC certificate number": "PUC000000",
    "driving licence number": "DL-0000000000000",
  
    "Ration card number": "RC0000000",
    "ABHA number": "ABHA0000000000",
    "PMJAY URN": "URN000000",
    "Medical record number": "MRN00000",
    "Insurance policy number": "POL000000",
    "UDID number": "UDID000000",
  
    "Employee ID": "EMP00000",
    "UAN": "100000000000",
    "ESIC IP number": "IP000000",
    "PRAN": "PRAN000000",
    "PPO number": "PPO000000",
  
    "Property registration number": "PRN000000",
    "Survey number": "SN00000",
    "Khasra number": "KH000000",
    "Khata number": "KT000000",
    "Khatauni number": "KUNI000000",
    "CTS number": "CTS00000",
    "Gata number": "GATA000000",
    "Patta number": "PATTA000000",
    "Mutation number": "MUT000000",
    "ROR number": "ROR000000",
    "Encumbrance certificate number": "EC000000",
    "Building plan approval number": "BPA000000",
    "Property tax assessment number": "PTA000000",
  
    "Student roll number": "ROLL0000",
    "Enrollment number": "ENR00000",
    "School admission number": "ADM00000",
  
    "Bar Council enrolment number": "BC000000",
    "Medical registration number": "MR000000",
    "CA membership number": "CA000000",
    "FSSAI license number": "FSSAI00000",
    "Drug license number": "DLN000000",
    "Trade license number": "TL000000",
  
    "Passport file number": "PFN000000",
    "Visa number": "VISA00000",
    "OCI card number": "OCI000000",
    "FRRO registration number": "FRRO00000",
  
    "Electricity consumer number": "ELEC000000",
    "Water connection number": "WCN000000",
    "LPG consumer number": "LPGC000000",
    "LPG ID": "LPGID00000",
  
    "IP address": "192.0.2.1",
    "MAC address": "00:00:00:00:00:00",
    "IMEI number": "000000000000000",
    "IMSI number": "404100000000000",
    "ICCID number": "89000000000000000000",
    "Device serial number": "SN0000000000",
  
    "Caste certificate number": "CC00000",
    "Income certificate number": "IC00000",
    "Domicile certificate number": "DC00000",
    "EWS certificate number": "EWS00000",
    "Marriage certificate number": "MC00000",
    "Birth certificate number": "BC00000",
    "Death certificate number": "DCN00000",
  
    "father's name": "Father Name",
    "mother's name": "Mother Name",
    "spouse name": "Spouse Name",
    "guardian name": "Guardian Name",
    "minor's name": "Minor Name",
    "date of birth": "01-01-2000",
    "place of birth": "Sample City",
    "age": "30",
  
    "photograph": "sample_photo.jpg",
    "signature": "sample_signature.png",
    "biometric data": ["biometric_template_sample", "biometric_template_sample_1", "biometric_template_sample_2", "biometric_template_sample_3", "biometric_template_sample_4"],
    "fingerprint data": ["fingerprint_sample", "fingerprint_sample_1", "fingerprint_sample_2", "fingerprint_sample_3", "fingerprint_sample_4"],
    "iris scan data": ["iris_sample", "iris_sample_1", "iris_sample_2", "iris_sample_3", "iris_sample_4"],
    "DNA profile": "DNA00000"
}
